searchData={"items":[{"type":"module","title":"CozyCase","doc":"Converts data between common multiple-word identifier formats, such as snake case, kebab case,\ncamel case and pascal case.\n\nCurrently, this module provides these main functions:\n\n+ `snake_case/1`\n+ `kebab_case/1`\n+ `camel_case/1`\n+ `pascal_case/1`","ref":"CozyCase.html"},{"type":"module","title":"Multiple-word identifier formats - CozyCase","doc":"| name        | example           |\n| ----------- | ----------------- |\n| snake case  | `welcome_message` |\n| kebab case  | `welcome-message` |\n| camel case  | `welcomeMessage`  |\n| pascal case | `WelcomeMessage`  |\n\n> Read [Examples of multiple-word identifier formats](https://en.wikipedia.org/w/index.php?title=Naming_convention_(programming)&oldid=1126175049#Examples_of_multiple-word_identifier_formats) for more unsupported formats.","ref":"CozyCase.html#module-multiple-word-identifier-formats"},{"type":"module","title":"Examples - CozyCase","doc":"All these functions have the same intefaces.\n\nFor strings or atoms, these functions convert them directly:\n\n    iex> CozyCase.snake_case(\"HelloWorld\")\n    \"hello_world\"\n\n    iex> CozyCase.snake_case(HelloWorld)\n    \"hello_world\"\n\nFor maps, these functions convert the keys of maps recursively, without touching the values\nof maps:\n\n    iex> CozyCase.snake_case(%{\n    ...>   \"FamilyMembers\" => [\n    ...>     %{\n    ...>       \"Name\" => \"Lily\",\n    ...>       \"Age\" => 50,\n    ...>       \"Hobbies\" => [\"Dreaming\", \"Singing\"]\n    ...>     },\n    ...>     %{\n    ...>       \"Name\" => \"Charlie\",\n    ...>       \"Age\" => 55,\n    ...>       \"Hobbies\" => [\"Dreaming\", \"Singing\"]\n    ...>     }\n    ...>   ]\n    ...> })\n    %{\n      \"family_members\" => [\n        %{\"name\" => \"Lily\", \"age\" => 50, \"hobbies\" => [\"Dreaming\", \"Singing\"]},\n        %{\"name\" => \"Charlie\", \"age\" => 55, \"hobbies\" => [\"Dreaming\", \"Singing\"]}\n      ]\n    }\n\nFor lists, these functions convert the keys of maps in lists recursively:\n\n    iex> CozyCase.snake_case([\n    ...>     %{\n    ...>       \"Name\" => \"Lily\",\n    ...>       \"Age\" => 50,\n    ...>       \"Hobbies\" => [\"Dreaming\", \"Singing\"]\n    ...>     },\n    ...>     %{\n    ...>       \"Name\" => \"Charlie\",\n    ...>       \"Age\" => 55,\n    ...>       \"Hobbies\" => [\"Dreaming\", \"Singing\"]\n    ...>     }\n    ...>   ])\n    [\n      %{\"name\" => \"Lily\", \"age\" => 50, \"hobbies\" => [\"Dreaming\", \"Singing\"]},\n      %{\"name\" => \"Charlie\", \"age\" => 55, \"hobbies\" => [\"Dreaming\", \"Singing\"]}\n    ]","ref":"CozyCase.html#module-examples"},{"type":"module","title":"Integrate with other packages - CozyCase","doc":"`CozyCase` doesn't provide higher-level wrappers. Because everything is a function, it's very\neasy to integrate `CozyCase` with other packages.\n\n### [`plug`](https://hexdocs.pm/plug)\n\nConverts params in `%Plug.Conn{}` to snake case:\n\n    defmodule DemoWeb.Plug.SnakeCaseParams do\n      @behaviour Plug\n\n      @impl true\n      def init(opts), do: opts\n\n      @impl true\n      def call(%{params: params} = conn, _opts) do\n        %{conn | params: CozyCase.snake_case(params)}\n      end\n    end\n\n### [`jason`](https://hexdocs.pm/jason)\n\nDecode a JSON string:\n\n    iex> json = \"{\\\"Age\\\":23,\\\"FamilyMembers\\\":[],\\\"Name\\\":\\\"Lenna\\\"}\"\n    iex> Jason.decode!(json, keys: &CozyCase.snake_case/1)\n    %{\"name\" => \"Lenna\", \"age\" => 23, \"family_members\" => []}\n\nEncode a map as a JSON string:\n\n    iex> map = %{\"name\" => \"Lenna\", \"age\" => 23, \"family_members\" => []}\n    iex> map |> CozyCase.camel_case() |> Jason.encode!()\n    \"{\\\"age\\\":23,\\\"familyMembers\\\":[],\\\"name\\\":\\\"Lenna\\\"}\"","ref":"CozyCase.html#module-integrate-with-other-packages"},{"type":"module","title":"Note - CozyCase","doc":"`CozyCase` is created for the convertion between common multiple-word identifier formats.\n\nBecause of that, `CozyCase` doesn't handle spaces which are not used as part of indentifier.\n\nAs the user of `CozyCase`, you should NOT pass string containing spaces, or the result will be\nsurprising.\n\n    iex> CozyCase.snake_case(\"welCome Message\")\n    \"wel_come message\"\n\n    iex> CozyCase.kebab_case(\"wel_Come Me_ssage\")\n    \"wel-come me-ssage\"","ref":"CozyCase.html#module-note"},{"type":"function","title":"CozyCase.camel_case/1","doc":"Converts other supported cases to camel case.","ref":"CozyCase.html#camel_case/1"},{"type":"function","title":"CozyCase.kebab_case/1","doc":"Converts other supported cases to kebab case.","ref":"CozyCase.html#kebab_case/1"},{"type":"function","title":"CozyCase.pascal_case/1","doc":"Converts other supported cases to pascal case.","ref":"CozyCase.html#pascal_case/1"},{"type":"function","title":"CozyCase.snake_case/1","doc":"Converts other supported cases to snake case.","ref":"CozyCase.html#snake_case/1"},{"type":"extras","title":"CozyCase","doc":"# CozyCase\n\n[![CI](https://github.com/cozy-elixir/cozy_case/actions/workflows/ci.yml/badge.svg)](https://github.com/cozy-elixir/cozy_case/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/cozy_case.svg)](https://hex.pm/packages/cozy_case)\n[![built with Nix](https://img.shields.io/badge/built%20with%20Nix-5277C3?logo=nixos&logoColor=white)](https://builtwithnix.org)\n\n> Converts data between common multiple-word identifier formats, such as snake case, kebab case, camel case and pascal case.","ref":"readme.html"},{"type":"extras","title":"Installation - CozyCase","doc":"Add `cozy_case` to the list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:cozy_case, \"~>  \"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - CozyCase","doc":"For more information, see the [documentation](https://hexdocs.pm/cozy_case/CozyCase.html).","ref":"readme.html#usage"},{"type":"extras","title":"Acknowledgments - CozyCase","doc":"This repo is forked from [nurugger07/inflex](https://github.com/nurugger07/inflex).","ref":"readme.html#acknowledgments"},{"type":"extras","title":"License - CozyCase","doc":"Apache License 2.0","ref":"readme.html#license"}],"content_type":"text/markdown"}